@@ -2,7 +2,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: opener.cpp 860924 2008-09-14 16:30:43Z woebbe $
+ * $Id: opener.cpp 1147199 2010-07-07 16:17:35Z pavelheimlich $
  *
  *              Copyright (C) 1997,98 Bernd Johannes Wuebben,
  *		                      Mario Weilguni
@@ -36,7 +36,7 @@
 #include <kdefakes.h>
 #include <config-kppp.h>
 
-#if defined(__osf__) || defined(__svr4__)
+#if defined(__osf__) || defined(__SVR4)
 #define _POSIX_PII_SOCKET
 extern "C" int sethostname(char *name, int name_len);
 #if !defined(__osf__)
@@ -654,7 +654,7 @@ int checkForInterface()
 // I don't know if Linux needs more initialization to get the ioctl to
 // work, pppd seems to hint it does.  But BSD doesn't, and the following
 // code should compile.
-#if (defined(HAVE_NET_IF_PPP_H) || defined(HAVE_LINUX_IF_PPP_H)) && !defined(__svr4__)
+#if (defined(HAVE_NET_IF_PPP_H) || defined(HAVE_LINUX_IF_PPP_H)) && !defined(__SVR4)
     int s, ok;
     struct ifreq ifr;
     //    extern char *no_ppp_msg;
